function [cineq, c, dcineq, dc] = GMMMPEC_c_ktr(x0) 

% GMMMPEC_c
% Constraints for the random coefficients Logit estimated via MPEC.
%
% source: Dube, Fox and Su (2012)
% Code Revised: January 2012

% Code Revised and Adapted for Gillen, Montero, Moon, & Shum (2019)
% BLP-2LASSO for Aggregate Discrete Choice Models with Rich Covariates
% Authors:  Ben Gillen, Sergio Montero, Roger Moon, & Matt Shum
% Last Edited:  April 23, 2019
% Last Run:  April 23, 2019
% Matlab Version - R2017b
%
% Modified function to account for two-dimensions in std deviation of taste
%
%Calls Function:
% ind_shnormMPEC

global x IV K JT T v nn share 
global prodsMarket marketStarts marketEnds

theta1 = x0(1:K, 1);                              % mean tastes
theta2 = x0(K+1:K+2, 1);                          % st. deviation of tastes
delta = x0(K+3:K+2+JT, 1);                 % mean utilities
g = x0(K+3+JT:end, 1);                       % moment condition values

cong = g - IV'*(delta - x*theta1);  % constraints on moment conditions

p = x(:,1:2);
expmu = exp(p*(repmat(theta2, 1, nn).*v));      % exponentiated deviations from mean utilities


expmeanval = exp(delta);
[EstShare, simShare] = ind_shnormMPEC(expmeanval,expmu);

cineq = [];
dcineq = [];

c = [EstShare - share ;
     cong ]; 
 
if nargout>2,
    p = x(:,1:2);
    ooonn = ones(nn, 1);
    ng = size(g,1);
    
    meanSimShare = mean(simShare, 2);
    % Evaluate the Gradients
    dSdtheta2 = zeros(JT,2);
    dSddelta = zeros(JT, JT);
    
    for t=1:T,
        index = marketStarts(t):marketEnds(t);
        ooo1 = ones(prodsMarket(t),1);
        dSdtheta2(index, 1)= mean((simShare(index,:)).*(v(ooo1, :))...
                                    .*( p(index, 1)*ooonn' - ((simShare(index,:)'*p(index, 1))*ooo1')' ), 2);
        dSdtheta2(index, 2)= mean((simShare(index,:)).*(v(2*ooo1, :))...
                                    .*( p(index, 2)*ooonn' - ((simShare(index,:)'*p(index, 2))*ooo1')' ), 2);
        dSddelta(index,index) = diag(meanSimShare(index)) ...
                                     - simShare(index, :)*simShare(index, :)'/nn;
    end


    dc1 = [zeros(JT,K), dSdtheta2, dSddelta, zeros(JT,ng)];
    dc2 = [IV'*x, zeros(ng, 2), -IV', eye(ng)];
    dc = [dc1; dc2]';
    
end