function [f, grad_f] = GMMMPEC_f_ktr(x0)

% GMMMPEC_f
% GMM Objective function for the random coefficients Logit esitmated via
% MPEC.
%
% source: Dube, Fox and Su (2012)
% Code Revised: January 2012

% Code Revised and Adapted for Gillen, Montero, Moon, & Shum (2019)
% BLP-2LASSO for Aggregate Discrete Choice Models with Rich Covariates
% Authors:  Ben Gillen, Sergio Montero, Roger Moon, & Matt Shum
% Last Edited:  April 23, 2019
% Last Run:  April 23, 2019
% Matlab Version - R2017b
%
% Modified function to allow for two-dimensions in std deviation of tastes


global W K JT delta

theta1 = x0(1:K, 1);       % mean tastes
theta2 = x0(K+1:K+2, 1);   % st. deviation of tastes
delta = x0(K+3:K+2+JT, 1); % mean utilities
g = x0(K+3+JT:end, 1);     % moment condition values

f = (g'*W*g); 

if nargout==2,
    nx0 = size(x0,1);
    grad_f = zeros(nx0,1);
    grad_f(K+3+JT:end,1) = 2*W*g;
end