function [hess] = GMMMPEC_hess_ktr(x0,lambda) 

% GMMMPEC_c
% Constraints for the random coefficients Logit estimated via MPEC.
%
% source: Dube, Fox and Su (2012)
% Code Revised: January 2012

% Code Revised and Adapted for Gillen, Montero, Moon, & Shum (2019)
% BLP-2LASSO for Aggregate Discrete Choice Models with Rich Covariates
% Authors:  Ben Gillen, Sergio Montero, Roger Moon, & Matt Shum
% Last Edited:  April 23, 2019
% Last Run:  April 23, 2019
% Matlab Version - R2017b
%
% Modified function to account for two-dimensions in std deviation of taste

global x K prods T v nn  W JT
global prodsMarket marketStarts marketEnds

theta1 = x0(1:K, 1);                              % mean tastes
theta2 = x0(K+1:K+2, 1);                          % st. deviation of tastes
delta = x0(K+3:K+2+JT, 1);                 % mean utilities
g = x0(K+3+JT:end, 1);                       % moment condition values
p = x(:, 1:2);

nx0 = size(x0,1);
ooo = ones(1,2);

hess = zeros(nx0, nx0);
hess(K+3+JT:end, K+3+JT:end) = 2*W;

expmu = exp(p*(repmat(theta2, 1, nn).*v));      % exponentiated deviations from mean utilities
expmeanval = exp(delta);
[~, simShare] = ind_shnormMPEC(expmeanval,expmu);

dL2dtheta22 = zeros(2,2);
dL2ddeltadtheta = zeros(JT, 2);
dL2ddelta2DIAG = zeros(JT,prods);
dL2ddelta2 = zeros(JT, JT);

% Evaluate the hessian    
for t=1:T,
    index = marketStarts(t):marketEnds(t);
    multip = lambda.eqnonlin(index);
    ooo1 = ones(prodsMarket(t),1);
    for rr = 1:nn,
            
        simS = simShare(index,rr);
        sumprod_mpsimS = multip'*simS;
            
        blk1 = sumprod_mpsimS*(-diag(simS) + 2*(simS*simS'));          
        blk2 = -(multip.*simS)*simS';
        blk3 = diag(multip.*simS);
        blk = blk1 + blk2 + blk2'+blk3;        
        dL2ddelta2DIAG(index,1:prodsMarket(t)) = dL2ddelta2DIAG(index,1:prodsMarket(t)) + blk/nn;
            

        xsimSx1 = p(index, 1) - (ooo1*(simS'*p(index, 1)));
        xsimSxv1 = xsimSx1.*v(rr);
        xsimSx2 = p(index, 2) - (ooo1*(simS'*p(index, 2)));
        xsimSxv2 = xsimSx2.*v(rr);

        simSxsimSxv1 = simS.*xsimSxv1;
        simSxsimSxv2 = simS.*xsimSxv2;
        dSdtheta2rr = [simSxsimSxv1, simSxsimSxv2];
     
        dL2ddeltadthetarr = -simS*multip'*dSdtheta2rr ...
                            - sumprod_mpsimS*dSdtheta2rr ...
                            + (multip*ooo).*dSdtheta2rr;    
                        
        dL2ddeltadtheta(index,:) = dL2ddeltadtheta(index,:) ...
                                     + dL2ddeltadthetarr/nn;
                                 
        dL2dtheta22rr = diag([((multip.*simSxsimSxv1)'*xsimSxv1)+...
                                    sumprod_mpsimS*(-simSxsimSxv1'*p(index, 1)*v(rr));
                               ((multip.*simSxsimSxv2)'*xsimSxv2)+...
                                    sumprod_mpsimS*(-simSxsimSxv2'*p(index, 2)*v(rr))]);  
                        
        dL2dtheta22 = dL2dtheta22 + dL2dtheta22rr/nn;
        
    end
    dL2ddelta2(index,index) = dL2ddelta2DIAG(index,1:prodsMarket(t));
end

hess(K+1:K+2,K+1:K+2) = dL2dtheta22;        
hess(K+3:K+2+JT,K+1:K+2) = dL2ddeltadtheta;    
hess(K+1:K+2,K+3:K+2+JT) = dL2ddeltadtheta';        
hess(K+3:K+2+JT, K+3:K+2+JT) = dL2ddelta2; 
    