function XInD = SelectControls(Y, X)

% BLP-2LASSO for Aggregate Discrete Choice Models with Rich Covariates
% Authors:  Ben Gillen, Sergio Montero, Roger Moon, & Matt Shum
% Accepted at Econometrics Journal
% Replication Code for Algorithm A.4 - Selecting Controls for RC Variance
% Instruments
% Last Edited:  April 23, 2019
% Last Run:  April 23, 2019
% Matlab Version - R2017b
%
% Function called by Table4_BLP_SelectedControls to select control
%     variables for instruments identifying standard deviations in taste
%     according to algorithm A.4.
%
%Inputs:  
%  Y - (JT x 1) Vector for Optimal Instrument to identify RC std's
%  X - (JT x K) Matrix of Controls for Consumer Preferences
%

%Outputs:  
%  XInD - (K x 1) Vector with entries equal to 1 if the control variable is
%                   selected into the model, 0 otherwise
%
%  Algorithm_5_2_I.mat - Matlab Workspace containing memory state at end of
%      function execution
%
%Calls Functions:  None
% 


%% Data Preparation

%Specify Parameters for Problem
T = size(Y, 1);
KT = size(X, 2);

gamma = 0.05/log(min(KT, T));
c = 1.1;
lambdaX = c*sqrt(T)*norminv(1-gamma/(2*KT))/(2*T);

%Initialization for Upsilon Matrices
UpsilonX = std(X);

xU = X./repmat(UpsilonX, T, 1);

%Iterative Algorithm for Upsilon Matrix
for j = 1:10
    [Bx, ~] = lasso(xU, Y, 'Lambda', lambdaX, 'Standardize', false);
    yResid = Y - xU*Bx;
    UpsilonX = sqrt(mean((X.^2).*(repmat(yResid, 1, KT).^2)));
    xU = X./repmat(UpsilonX, T, 1);
end

%Lasso for Selection
[Bx, ~] = lasso(xU, Y, 'Lambda', lambdaX, 'Standardize', false);


XInD = logical([true*ones(11, 1); ((abs(Bx(12:end))>0.001))>0]);