function PROB = ind_shnormMX(expmeanval,expmu)

% IND_SHNORM
% This function computes the "individual" probabilities of choosing each brand.
% The probabilities are those associated with the normally-distributed r.c. logit.
%
% ARGUMENTS:
% expmeanval = vector of exponentiated mean utilities, sorted by market then product
% expmu = matrix of exponentiated draws of deviations from mean utilities, sorted by market then product
%
% OUTPUT:
% PROB = vector of expected market shares, sorted by market then product
% source: Dube, Fox and Su (2012)
% Code Revised: January 2012

% Code utilized in Gillen, Montero, Moon, & Shum (2019)
% BLP-2LASSO for Aggregate Discrete Choice Models with Rich Covariates
% Authors:  Ben Gillen, Sergio Montero, Roger Moon, & Matt Shum
% Last Edited:  April 23, 2019
% Last Run:  April 23, 2019
% Matlab Version - R2017b

global oo sharesum SS

numer = (expmeanval*oo ).*expmu;        % this is the numerator 
sum1 = sharesum*numer;
SS = numer./(1+sum1);                    % this is the denominator of the shares
PROB = mean(SS,2);                      % expected share (i.e. mean across draws)
