function Ddelta = jacobian(theta2)

% JACOBIAN
% Computes the Jacobian of the mean utilities associated with
% the random coefficients Logit demand model.
%
% source: Dube, Fox and Su (2012)
% Code Revised: January 2012

% Code Revised and Adapted for Gillen, Montero, Moon, & Shum (2019)
% BLP-2LASSO for Aggregate Discrete Choice Models with Rich Covariates
% Authors:  Ben Gillen, Sergio Montero, Roger Moon, & Matt Shum
% Last Edited:  April 23, 2019
% Last Run:  April 23, 2019
% Matlab Version - R2017b
%
% Modified function to allow for two-dimensions in std deviation of tastes


global prods T nn v K x delta
global prodsMarket numProdsTotal marketStarts marketEnds

p = x(:,1:2);
expmu = exp(p*(repmat(theta2, 1, nn).*v));      % exponentiated deviations from mean utilities
expmeanval = exp(delta);
[EstShare, simShare] = ind_shnormMPEC(expmeanval,expmu);

ooo = ones(1,K+1);

ooonn = ones(nn, 1);
meanSimShare = mean(simShare, 2);
% Evaluate the Gradients
dSdtheta2 = zeros(numProdsTotal,2);
dSddeltaDIAG = zeros(numProdsTotal,prods);
dSddelta = zeros(numProdsTotal, numProdsTotal);

for t=1:T,
    index = marketStarts(t):marketEnds(t);
    ooo1 = ones(prodsMarket(t),1);
    dSddeltaDIAG(index,1:prodsMarket(t)) = diag(meanSimShare(index)) ...
                    - simShare(index, :)*simShare(index, :)'/nn;
    dSdtheta2(index,1)= mean((simShare(index,:)).*(v(ooo1, :))...
                                .*( p(index, 1)*ooonn' - ((simShare(index,:)'*p(index, 1))*ooo1')' ), 2);
    dSdtheta2(index,2)= mean((simShare(index,:)).*(v(ooo1, :))...
                                .*( p(index, 2)*ooonn' - ((simShare(index,:)'*p(index, 2))*ooo1')' ), 2);
    dSddelta(index,index) = dSddeltaDIAG(index,1:prodsMarket(t));
end


Ddelta = -inv(dSddelta)*dSdtheta2;



